@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmi-fru-info-area.c,v 1.15.4.1 2009/04/09 00:09:41 chu11 Exp $
+ *  $Id: ipmi-fru-info-area.c,v 1.15.4.4 2009/04/16 22:34:30 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
@@ -118,11 +118,11 @@ ipmi_fru_output_chassis_info_area(ipmi_fru_state_data_t *state_data,
 
   if (IPMI_FRU_CHASSIS_TYPE_VALID (chassis_type))
     pstdout_printf (state_data->pstate,
-                    "  Chassis Info Area Type: %s\n",
+                    "  FRU Chassis Info Area Type: %s\n",
                     ipmi_fru_chassis_types[chassis_type]);
   else
     pstdout_printf (state_data->pstate,
-                    "  Chassis Info Area Type: %s\n",
+                    "  FRU Chassis Info Area Type: %s\n",
                     ipmi_fru_chassis_types[IPMI_FRU_CHASSIS_TYPE_UNKNOWN]);
   
   chassis_offset++;
@@ -543,7 +543,7 @@ ipmi_fru_output_product_info_area(ipmi_fru_state_data_t *state_data,
                                                product_offset,
                                                &language_code,
                                                &len_parsed,
-                                               "Product Product Name")) != FRU_ERR_SUCCESS)
+                                               "Product Name")) != FRU_ERR_SUCCESS)
     {
       pstdout_fprintf(state_data->pstate, 
                       stderr,
@@ -577,7 +577,7 @@ ipmi_fru_output_product_info_area(ipmi_fru_state_data_t *state_data,
                                                product_offset,
                                                &language_code,
                                                &len_parsed,
-                                               "Product Version Type")) != FRU_ERR_SUCCESS)
+                                               "Product Version")) != FRU_ERR_SUCCESS)
     {
       pstdout_fprintf(state_data->pstate, 
                       stderr,
