@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmi_monitoring_ipmi_communication.h,v 1.6 2007/10/18 16:18:50 chu11 Exp $
+ *  $Id: ipmi_monitoring_ipmi_communication.h,v 1.8 2008/03/28 00:14:43 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -35,11 +35,7 @@ int ipmi_monitoring_ipmi_communication_init(ipmi_monitoring_ctx_t c,
                                             const char *hostname,
                                             struct ipmi_monitoring_ipmi_config *config);
 
-int ipmi_monitoring_ipmi_sendrecv(ipmi_monitoring_ctx_t c,
-                                  uint8_t lun,
-                                  uint8_t net_fn,
-                                  fiid_obj_t obj_cmd_rq,
-                                  fiid_obj_t obj_cmd_rs);
+void ipmi_monitoring_ipmi_ctx_error_convert(ipmi_monitoring_ctx_t c);
 
 int ipmi_monitoring_ipmi_communication_cleanup(ipmi_monitoring_ctx_t c);
 
